%if 0%{?fedora} || 0%{?rhel} == 6
%global with_devel 1
%global with_bundled 0
%global with_debug 0
%global with_check 1
%global with_unit_test 1
%else
%global with_devel 0
%global with_bundled 0
%global with_debug 0
%global with_check 0
%global with_unit_test 0
%endif

%if 0%{?with_debug}
%global _dwz_low_mem_die_limit 0
%else
%global debug_package   %{nil}
%endif

%global provider        github
%global provider_tld    com
%global project         prometheus
%global repo            client_golang
# https://github.com/prometheus/client_golang
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global commit          e51041b3fa41cece0dca035740ba6411905be473
%global shortcommit     %(c=%{commit}; echo ${c:0:7})

Name:           golang-%{provider}-%{project}-%{repo}
Version:        0.7.0
Release:        1%{?dist}
Summary:        Prometheus instrumentation library for Go applications
License:        ASL 2.0
URL:            https://%{provider_prefix}
Source0:        https://%{provider_prefix}/archive/%{commit}/%{repo}-%{shortcommit}.tar.gz

# If go_arches not defined fall through to implicit golang archs
%if 0%{?go_arches:1}
ExclusiveArch:  %{go_arches}
%else
ExclusiveArch:   %{ix86} x86_64 %{arm}
%endif
# If gccgo_arches does not fit or is not defined fall through to golang
%ifarch 0%{?gccgo_arches}
BuildRequires:   gcc-go >= %{gccgo_min_vers}
%else
BuildRequires:   golang
%endif

%description
%{summary}

%if 0%{?with_devel}
%package devel
Summary:       %{summary}
BuildArch:     noarch

%if 0%{?with_check}
BuildRequires: golang(github.com/beorn7/perks/quantile)
BuildRequires: golang(github.com/golang/protobuf/proto)
BuildRequires: golang(github.com/prometheus/common/expfmt)
BuildRequires: golang(github.com/prometheus/common/model)
BuildRequires: golang(github.com/prometheus/procfs)
BuildRequires: golang(golang.org/x/net/context)
BuildRequires: golang(golang.org/x/net/context/ctxhttp)
%endif

Requires:      golang(github.com/beorn7/perks/quantile)
Requires:      golang(github.com/golang/protobuf/proto)
Requires:      golang(github.com/prometheus/common/expfmt)
Requires:      golang(github.com/prometheus/common/model)
Requires:      golang(github.com/prometheus/procfs)
Requires:      golang(golang.org/x/net/context)
Requires:      golang(golang.org/x/net/context/ctxhttp)

Provides:      golang(%{import_path}/api/prometheus) = %{version}-%{release}
Provides:      golang(%{import_path}/prometheus) = %{version}-%{release}

%description devel
%{summary}

This package contains library source intended for
building other packages which use import path with
%{import_path} prefix.
%endif

%if 0%{?with_unit_test}
%package unit-test
Summary:         Unit tests for %{name} package
# If go_arches not defined fall through to implicit golang archs
%if 0%{?go_arches:1}
ExclusiveArch:  %{go_arches}
%else
ExclusiveArch:   %{ix86} x86_64 %{arm}
%endif
# If gccgo_arches does not fit or is not defined fall through to golang
%ifarch 0%{?gccgo_arches}
BuildRequires:   gcc-go >= %{gccgo_min_vers}
%else
BuildRequires:   golang
%endif

%if 0%{?with_check}
#Here comes all BuildRequires: PACKAGE the unit tests
#in %%check section need for running
%endif

# test subpackage tests code from devel subpackage
Requires:        %{name}-devel = %{version}-%{release}

%description unit-test
%{summary}

This package contains unit tests for project
providing packages with %{import_path} prefix.
%endif

%prep
%setup -q -n %{repo}-%{commit}

%build

%install
# source codes for building projects
%if 0%{?with_devel}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *.go but no *_test.go files and generate devel.file-list
for file in $(find . -iname "*.go" \! -iname "*_test.go") ; do
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> devel.file-list
done
%endif

# testing files for this project
%if 0%{?with_unit_test}
install -d -p %{buildroot}/%{gopath}/src/%{import_path}/
# find all *_test.go files and generate unit-test.file-list
for file in $(find . -iname "*_test.go"); do
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test.file-list
done
for file in $(find ./extraction/ -iname "*.json"); do
    install -d -p %{buildroot}/%{gopath}/src/%{import_path}/$(dirname $file)
    cp -pav $file %{buildroot}/%{gopath}/src/%{import_path}/$file
    echo "%%{gopath}/src/%%{import_path}/$file" >> unit-test.file-list
done
%endif

%check
%if 0%{?with_check} && 0%{?with_unit_test} && 0%{?with_devel}
%ifarch 0%{?gccgo_arches}
function gotest { %{gcc_go_test} "$@"; }
%else
%if 0%{?golang_test:1}
function gotest { %{golang_test} "$@"; }
%else
function gotest { go test "$@"; }
%endif
%endif

export GOPATH=%{buildroot}/%{gopath}:%{gopath}
# Test failed on x86_64: signature_test.go:265: expected LabelsToSignature with
# empty labels not to perform allocations
#gotest %{import_path}/model
# Test failed on i686: go_collector_test.go:108: want 1 new garbage collection
# run, got 2
#gotest %{import_path}/prometheus
gotest %{import_path}/api/prometheus
%endif

#define license tag if not already defined
%{!?_licensedir:%global license %doc}

%if 0%{?with_devel}
%files devel -f devel.file-list
%license LICENSE
%doc README.md CONTRIBUTING.md AUTHORS.md CHANGELOG.md
%dir %{gopath}/src/%{provider}.%{provider_tld}/%{project}
%dir %{gopath}/src/%{import_path}
%endif

%if 0%{?with_unit_test}
%files unit-test -f unit-test.file-list
%license LICENSE
%doc README.md CONTRIBUTING.md AUTHORS.md CHANGELOG.md
%endif

%changelog
* Mon Oct 19 2015 jchaloup <jchaloup@redhat.com> - 0.7.0-1
- Bump to upstream e51041b3fa41cece0dca035740ba6411905be473
  related: #1214784

* Mon Aug 17 2015 jchaloup <jchaloup@redhat.com> - 0.6.0-3
- Add Godeps.json to doc
  related: #1214784

* Fri Aug 07 2015 Fridolin Pokorny <fpokorny@redhat.com> - 0.6.0-2
- Update spec file to spec-2.0
- Disabled failing test prometheus
- Disabled failing test model
  resolves: #1214784

* Thu Jul 23 2015 Fridolin Pokorny <fpokorny@redhat.com> - 0.6.0-1
- Bump to upstream 36659fa1ad85ee0dd33822b68a192a814c93a57b
  related: #1214784

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon May 11 2015 jchaloup <jchaloup@redhat.com> - 0.5.0-1
- Bump to upstream b0bd7e1be33327b85cb4853e7011156e3cedd657
  related: #1214784

* Thu Apr 23 2015 jchaloup <jchaloup@redhat.com> - 0.4.0-1
- Bump to upstream 608ec8b69e284600a7ad1b36514a1e6876e22b9f
  resolves: #1214784

* Wed Mar 04 2015 jchaloup <jchaloup@redhat.com> - 0-0.3.gite5098ac
- Bump to upstream e5098ac1ff13c7f85b68b120b253dd834ba49682
  related: #1190442

* Thu Feb 26 2015 jchaloup <jchaloup@redhat.com> - 0-0.2.git39e4bc8
- Bump to upstream 39e4bc83f974fb141a9e67c042b26322bacc917b
  related: #1190442

* Sat Feb 07 2015 jchaloup <jchaloup@redhat.com> - 0-0.1.git52186fc
- First package for Fedora
  resolves: #1190442

